package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcBudgetDevice;

/**
 * cmc设备预算Service接口
 * 
 * @author cmc
 * @date 2024-03-22
 */
public interface ICmcBudgetDeviceService 
{
    /**
     * 查询cmc设备预算
     * 
     * @param budgetId cmc预算id
     * @return cmc设备预算
     */
    public List<CmcBudgetDevice> selectCmcBudgetDeviceByBudgetId(String budgetId);

    /**
     * 查询cmc设备预算列表
     * 
     * @param cmcBudgetDevice cmc设备预算
     * @return cmc设备预算集合
     */
    public List<CmcBudgetDevice> selectCmcBudgetDeviceList(CmcBudgetDevice cmcBudgetDevice);

    /**
     * 新增cmc设备预算
     * 
     * @param cmcBudgetDevice cmc设备预算
     * @return 结果
     */
    public int insertCmcBudgetDevice(CmcBudgetDevice cmcBudgetDevice);

    /**
     * 修改cmc设备预算
     * 
     * @param cmcBudgetDevice cmc设备预算
     * @return 结果
     */
    public int updateCmcBudgetDevice(CmcBudgetDevice cmcBudgetDevice);

    /**
     * 批量删除cmc设备预算
     * 
     * @param budgetIds 需要删除的cmc设备预算主键集合
     * @return 结果
     */
    public int deleteCmcBudgetDeviceByBudgetIds(String[] budgetIds);

    /**
     * 删除cmc设备预算信息
     * 
     * @param budgetId cmc设备预算主键
     * @return 结果
     */
    public int deleteCmcBudgetDeviceByBudgetId(String budgetId);
}
